==> eg_particle_interactions-v0.8-fabric-mc1.21.8-sources.jar: games/enchanted/eg_particle_interactions/common/particle/swirling/WaterVapour.java <==
package games.enchanted.eg_particle_interactions.common.particle.swirling;

import games.enchanted.eg_particle_interactions.common.util.MathHelpers;
import net.minecraft.class_2400;
import net.minecraft.class_4002;
import net.minecraft.class_638;
import net.minecraft.class_703;
import net.minecraft.class_707;
import org.jetbrains.annotations.NotNull;
import org.jetbrains.annotations.Nullable;

public class WaterVapour extends SwirlingParticle {
    protected final class_4002 sprites;

    protected WaterVapour(class_638 level, double x, double y, double z, double xSpeed, double ySpeed, double zSpeed, class_4002 spriteSet, boolean shouldSwirl) {
        super(level, x, y, z, xSpeed, ySpeed, zSpeed, spriteSet, shouldSwirl);
        this.sprites = spriteSet;
        this.method_18142(sprites);
        this.setInitialVelocity(xSpeed, ySpeed, zSpeed, 0.015f);

        this.field_3844 = MathHelpers.randomBetween(-0.04f, -0.07f);

        this.field_3847 = MathHelpers.randomBetween(4, 15);

        this.rotSpeed = 0f;
        this.spinAcceleration = 0f;
        this.swirlStrength = MathHelpers.randomBetween(3f, 6f) * (level.field_9229.method_43056() ? -1 : 1);
        this.swirlPeriod = MathHelpers.randomBetween(1, 4);

        this.field_17867 = 2f/32f;
        this.method_3080(1f/32f, 1f/32f);
    }

    @Override
    public void method_3070() {
        method_18142(this.sprites);
        super.method_3070();
    }

    public static class WaterVapourProvider implements class_707<class_2400> {
        private final class_4002 spriteSet;

        public WaterVapourProvider(class_4002 spriteSet) {
            this.spriteSet = spriteSet;
        }

        @Nullable
        @Override
        public class_703 createParticle(@NotNull class_2400 type, @NotNull class_638 level, double x, double y, double z, double xSpeed, double ySpeed, double zSpeed) {
            return new WaterVapour(level, x, y, z, xSpeed, ySpeed, zSpeed, spriteSet, true);
        }
    }
}

==> eg_particle_interactions-v0.8.4-fabric-mc1.21.8-sources.jar: games/enchanted/eg_particle_interactions/common/particle/swirling/WaterVapour.java <==
package games.enchanted.eg_particle_interactions.common.particle.swirling;

import games.enchanted.eg_particle_interactions.common.util.MathHelpers;
import net.minecraft.class_2400;
import net.minecraft.class_4002;
import net.minecraft.class_638;
import net.minecraft.class_703;
import net.minecraft.class_707;
import org.jetbrains.annotations.Nullable;

public class WaterVapour extends SwirlingParticle {
    protected final class_4002 sprites;

    protected WaterVapour(class_638 level, double x, double y, double z, double xSpeed, double ySpeed, double zSpeed, class_4002 spriteSet, boolean shouldSwirl) {
        super(level, x, y, z, xSpeed, ySpeed, zSpeed, spriteSet, shouldSwirl);
        this.sprites = spriteSet;
        this.setSpriteFromAge(sprites);
        this.setInitialVelocity(xSpeed, ySpeed, zSpeed, 0.015f);

        this.field_3844 = MathHelpers.randomBetween(-0.04f, -0.07f);

        this.field_3847 = MathHelpers.randomBetween(4, 15);

        this.rotSpeed = 0f;
        this.spinAcceleration = 0f;
        this.swirlStrength = MathHelpers.randomBetween(3f, 6f) * (level.field_9229.method_43056() ? -1 : 1);
        this.swirlPeriod = MathHelpers.randomBetween(1, 4);

        this.setScale(2f/32f);
        this.method_3080(1f/32f, 1f/32f);
    }

    @Override
    public void method_3070() {
        setSpriteFromAge(this.sprites);
        super.method_3070();
    }

    public static class WaterVapourProvider implements class_707<class_2400> {
        private final class_4002 spriteSet;

        public WaterVapourProvider(class_4002 spriteSet) {
            this.spriteSet = spriteSet;
        }

        @Override
        public @Nullable class_703 createParticle(
            class_2400 options,
            class_638 level,
            double x,
            double y,
            double z,
            double xSpeed,
            double ySpeed,
            double zSpeed
            //? if minecraft: > 1.21.8 {
            /*, RandomSource random
            *///?}
        ) {
            return new WaterVapour(level, x, y, z, xSpeed, ySpeed, zSpeed, spriteSet, true);
        }
    }
}
